/*
    Freud - a standalone C++ port of the Emacs Psychiatrist
    Copyright (C) 2002  Markus Triska

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    You can contact me via triska@gmx.at
*/


#include <map>
#include <string>
#include <sstream>
#include <vector>
#include <algorithm>

#include "synonymlist.h"

using namespace std;

string SynonymList::current()
{
	// Return a synonym of this class, and advance for next call.
	if (!synonyms.size()) { return ""; }
	string retstr = synonyms[index++];
	if (index >= synonyms.size()) { index = 0; }

	return retstr;
}

SynonymList& SynonymList::add(const string &syn)
{
	synonyms.push_back(syn);
	return *this;
}

bool SynonymList::isMember(const string &syn)
{
	return (find(synonyms.begin(), synonyms.end(), syn) != synonyms.end());
}

/*
	The remaining procedures in this file initialize the "meanings" of some
	common words and set up the "synonyms"-table used for replies to these
	words.

	The initialization code is rather lengthy - I split it up into several
	procedures to give the compiler a chance (G++ 2.95.3 fails to compile
	so long a function with -O2, at least on my machine configuration).
	This is yet another reason for translating this code to some syntax
	that can be used in a configuration file read in at runtime.
*/

extern map<string, string> meanings;
extern map<string, SynonymList> synonyms;
extern map<string, string> replist;
extern map<string, string> corrections;
extern map<string, string> expansions;


void setmeaning(const string &symb, const string &val)
{
	meanings[symb] = val;
}

void set_correct_expand(const string &s1, const string &s2, const string &s3)
{
	corrections[s1] = s2;
	expansions[s2] = s3;
}

void init_meanings1()
{
	setmeaning("howdy", "howdy"); setmeaning("hi", "howdy");
	setmeaning("greetings", "howdy"); setmeaning("hello", "howdy");
	setmeaning("tops20", "mach"); setmeaning("tops-20", "mach");
	setmeaning("tops", "mach"); setmeaning("pdp11", "mach");
	setmeaning("computer", "mach"); setmeaning("unix", "mach");
	setmeaning("machine", "mach"); setmeaning("computers", "mach");
	setmeaning("machines", "mach"); setmeaning("pdp11s", "mach");
	setmeaning("foo", "mach"); setmeaning("foobar", "mach");
	setmeaning("multics", "mach"); setmeaning("macsyma", "mach");
	setmeaning("teletype", "mach"); setmeaning("la36", "mach");
	setmeaning("vt52", "mach"); setmeaning("zork", "mach");
	setmeaning("trek", "mach"); setmeaning("startrek", "mach");
	setmeaning("advent", "mach"); setmeaning("pdp", "mach");
	setmeaning("dec", "mach"); setmeaning("commodore", "mach");
	setmeaning("vic", "mach"); setmeaning("bbs", "mach");
	setmeaning("modem", "mach"); setmeaning("baud", "mach");
	setmeaning("macintosh", "mach"); setmeaning("vax", "mach");
	setmeaning("vms", "mach"); setmeaning("ibm", "mach");
	setmeaning("pc", "mach"); setmeaning("bitching", "foul");
	setmeaning("shit", "foul"); setmeaning("bastard", "foul");
	setmeaning("damn", "foul"); setmeaning("damned", "foul");
	setmeaning("hell", "foul"); setmeaning("suck", "foul");
	setmeaning("sucking", "foul"); setmeaning("sux", "foul");
	setmeaning("ass", "foul"); setmeaning("whore", "foul");
	setmeaning("bitch", "foul"); setmeaning("asshole", "foul");
	setmeaning("shrink", "foul"); setmeaning("pot", "toke");
	setmeaning("grass", "toke"); setmeaning("weed", "toke");
	setmeaning("marijuana", "toke"); setmeaning("acapulco", "toke");
	setmeaning("columbian", "toke"); setmeaning("tokin", "toke");
	setmeaning("joint", "toke"); setmeaning("toke", "toke");
	setmeaning("toking", "toke"); setmeaning("tokin\'", "toke");
	setmeaning("toked", "toke"); setmeaning("roach", "toke");
	setmeaning("pills", "drug"); setmeaning("dope", "drug");
	setmeaning("acid", "drug"); setmeaning("lsd", "drug");
	setmeaning("speed", "drug"); setmeaning("heroin", "drug");
	setmeaning("hash", "drug"); setmeaning("cocaine", "drug");
	setmeaning("uppers", "drug"); setmeaning("downers", "drug");
	setmeaning("loves", "loves"); setmeaning("love", "love");
	setmeaning("loved", "love"); setmeaning("hates", "hates");
	setmeaning("dislikes", "hates"); setmeaning("hate", "hate");
	setmeaning("hated", "hate"); setmeaning("dislike", "hate");
	setmeaning("stoned", "state"); setmeaning("drunk", "state");
	setmeaning("drunken", "state"); setmeaning("high", "state");
	setmeaning("horny", "state"); setmeaning("blasted", "state");
	setmeaning("happy", "state"); setmeaning("paranoid", "state");
	setmeaning("wish", "desire"); setmeaning("wishes", "desire");
	setmeaning("want", "desire"); setmeaning("desire", "desire");
	setmeaning("like", "desire"); setmeaning("hope", "desire");
	setmeaning("hopes", "desire"); setmeaning("desires", "desire");
	setmeaning("wants", "desire"); setmeaning("desires", "desire");
}

void init_meanings2()
{
	setmeaning("likes", "desire"); setmeaning("needs", "desire");
	setmeaning("need", "desire"); setmeaning("frustrated", "mood");
	setmeaning("depressed", "mood"); setmeaning("annoyed", "mood");
	setmeaning("upset", "mood"); setmeaning("unhappy", "mood");
	setmeaning("excited", "mood"); setmeaning("worried", "mood");
	setmeaning("lonely", "mood"); setmeaning("angry", "mood");
	setmeaning("mad", "mood"); setmeaning("pissed", "mood");
	setmeaning("jealous", "mood"); setmeaning("afraid", "fear");
	setmeaning("terrified", "fear"); setmeaning("fear", "fear");
	setmeaning("scared", "fear"); setmeaning("frightened", "fear");
	setmeaning("virginity", "sexnoun"); setmeaning("virgins", "sexnoun");
	setmeaning("virgin", "sexnoun"); setmeaning("cock", "sexnoun");
	setmeaning("cocks", "sexnoun"); setmeaning("dick", "sexnoun");
	setmeaning("dicks", "sexnoun"); setmeaning("cunt", "sexnoun");
	setmeaning("cunts", "sexnoun"); setmeaning("prostitute", "sexnoun");
	setmeaning("condom", "sexnoun"); setmeaning("sex", "sexnoun");
	setmeaning("rapes", "sexnoun"); setmeaning("wife", "family");
	setmeaning("family", "family"); setmeaning("brothers", "family");
	setmeaning("sisters", "family"); setmeaning("parent", "family");
	setmeaning("parents", "family"); setmeaning("brother", "family");
	setmeaning("sister", "family"); setmeaning("father", "family");
	setmeaning("mother", "family"); setmeaning("husband", "family");
	setmeaning("siblings", "family"); setmeaning("grandmother", "family");
	setmeaning("grandfather", "family"); setmeaning("maternal", "family");
	setmeaning("paternal", "family"); setmeaning("stab", "death");
	setmeaning("murder", "death"); setmeaning("murders", "death");
	setmeaning("suicide", "death"); setmeaning("suicides", "death");
	setmeaning("kill", "death"); setmeaning("kills", "death");
	setmeaning("killing", "death"); setmeaning("die", "death");
	setmeaning("dies", "death"); setmeaning("died", "death");
	setmeaning("dead", "death"); setmeaning("death", "death");
	setmeaning("deaths", "death"); setmeaning("pain", "symptoms");
	setmeaning("ache", "symptoms"); setmeaning("fever", "symptoms");
	setmeaning("sore", "symptoms"); setmeaning("aching", "symptoms");
	setmeaning("stomachache", "symptoms");
	setmeaning("headache", "symptoms");

}

void init_meanings()
{
	init_meanings1();
	init_meanings2();
	setmeaning("hurts", "symptoms"); setmeaning("disease", "symptoms");
	setmeaning("virus", "symptoms"); setmeaning("vomit", "symptoms");
	setmeaning("vomiting", "symptoms"); setmeaning("barf", "symptoms");
	setmeaning("toothache", "symptoms"); setmeaning("hurt", "symptoms");
	setmeaning("rum", "alcohol"); setmeaning("gin", "alcohol");
	setmeaning("vodka", "alcohol"); setmeaning("alcohol", "alcohol");
	setmeaning("bourbon", "alcohol"); setmeaning("beer", "alcohol");
	setmeaning("wine", "alcohol"); setmeaning("whiskey", "alcohol");
	setmeaning("scotch", "alcohol"); setmeaning("fuck", "sexverb");
	setmeaning("fucked", "sexverb"); setmeaning("screw", "sexverb");
	setmeaning("screwing", "sexverb"); setmeaning("fucking", "sexverb");
	setmeaning("rape", "sexverb"); setmeaning("raped", "sexverb");
	setmeaning("kiss", "sexverb"); setmeaning("kissing", "sexverb");
	setmeaning("kisses", "sexverb"); setmeaning("screws", "sexverb");
	setmeaning("fucks", "sexverb"); setmeaning("because", "conj");
	setmeaning("but", "conj"); setmeaning("however", "conj");
	setmeaning("besides", "conj"); setmeaning("anyway", "conj");
	setmeaning("that", "conj"); setmeaning("except", "conj");
	setmeaning("why", "conj"); setmeaning("how", "conj");
	setmeaning("until", "when"); setmeaning("when", "when");
	setmeaning("whenever", "when"); setmeaning("while", "when");
	setmeaning("since", "when"); setmeaning("rms", "rms");
	setmeaning("stallman", "rms"); setmeaning("school", "school");
	setmeaning("schools", "school"); setmeaning("skool", "school");
	setmeaning("grade", "school"); setmeaning("grades", "school");
	setmeaning("teacher", "school"); setmeaning("teachers", "school");
	setmeaning("classes", "school"); setmeaning("professor", "school");
	setmeaning("prof", "school"); setmeaning("profs", "school");
	setmeaning("professors", "school"); setmeaning("mit", "school");
	setmeaning("emacs", "eliza"); setmeaning("eliza", "eliza");
	setmeaning("liza", "eliza"); setmeaning("elisa", "eliza");
	setmeaning("weizenbaum", "eliza"); setmeaning("doktor", "eliza");
	setmeaning("athletics", "sports"); setmeaning("baseball", "sports");
	setmeaning("basketball", "sports"); setmeaning("football", "sports");
	setmeaning("frisbee", "sports"); setmeaning("gym", "sports");
	setmeaning("gymnastics", "sports"); setmeaning("hockey", "sports");
	setmeaning("lacrosse", "sports"); setmeaning("soccer", "sports");
	setmeaning("softball", "sports"); setmeaning("sports", "sports");
	setmeaning("swimming", "sports"); setmeaning("swim", "sports");
	setmeaning("tennis", "sports"); setmeaning("volleyball", "sports");
	setmeaning("math", "math"); setmeaning("mathematics", "math");
	setmeaning("mathematical", "math"); setmeaning("theorem", "math");
	setmeaning("axiom", "math"); setmeaning("lemma", "math");
	setmeaning("algebra", "math"); setmeaning("algebraic", "math");
	setmeaning("trig", "math"); setmeaning("trigonometry", "math");
	setmeaning("trigonometric", "math"); setmeaning("geometry", "math");
	setmeaning("geometric", "math"); setmeaning("calculus", "math");
	setmeaning("arithmetic", "math"); setmeaning("zippy", "zippy");
	setmeaning("zippy", "zippy"); setmeaning("pinhead", "zippy");
	setmeaning("chat", "chat");
}

void init_corrections()
{
	set_correct_expand("theyll", "they'll", "they will");
	set_correct_expand("theyre", "they're", "they are");
	set_correct_expand("hes", "he's", "he is");
	set_correct_expand("he7s", "he's", "he is");
	set_correct_expand("im", "i'm", "you are");
	set_correct_expand("i7m", "i'm", "you are");
	set_correct_expand("isa", "is a", "is a");
	set_correct_expand("thier", "their", "their");
	set_correct_expand("dont", "don't", "do not");
	set_correct_expand("don7t", "don't", "do not");
	set_correct_expand("you7re", "you're", "i am");
	set_correct_expand("you7ve", "you've", "i have");
	set_correct_expand("you7ll", "you'll", "i will");

	replist["i"] = "you"; replist["my"] = "your"; replist["me"] = "you";
	replist["you"] = "me"; replist["your"] = "my";
	replist["mine"] = "yours"; replist["our"] = "your";
	replist["ours"] = "yours"; replist["we"] = "you";
	replist["dunno"] = "do not know";
	replist["no,"] = ""; replist["yes,"] = ""; replist["ya"] = "i";
	replist["aint"] = "am not"; replist["wanna"] = "want to";
	replist["gimme"] = "give me"; replist["gotta"] = "have to";
	replist["gonna"] = "going to"; replist["never"] = "not ever";
	replist["doesn't"] = "does not"; replist["don't"] = "do not";
	replist["aren't"] = "are not"; replist["isn't"] = "is not";
	replist["won't"] = "will not"; replist["can't"] = "cannot";
	replist["haven't"] = "have not"; replist["i'm"] = "you are";
	replist["ourselves"] = "yourselves"; replist["myself"] = "yourself";
	replist["yourself"] = "myself"; replist["you're"] = "i am";
	replist["you've"] = "i have"; replist["i've"] = "you have";
	replist["i'll"] = "you will"; replist["you'll"] = "i shall";
	replist["i'd"] = "you would"; replist["you'd"] = "i would";
	replist["here"] = "there"; replist["please"] = "";
	replist["eh,"] = ""; replist["eh"] = ""; replist["oh,"] = "";
	replist["oh"] = ""; replist["shouldn't"] = "should not";
	replist["wouldn't"] = "would not"; replist["won't"] = "will not";
	replist["won't"] = "will not"; replist["hasn't"] = "has not";
}

void init_synonyms1()
{
	SynonymList syn;

	syn.clear();
	syn.add("well,").add("hmmm ... so,").add("so").add("...and");
	syn.add("then");
	synonyms["inter"] = syn;

	syn.clear();
	syn.add("continue").add("proceed").add("go on").add("keep going");
	synonyms["continue"] = syn;

	syn.clear();
	syn.add("your relationship with").add("something you remember about");
	syn.add("your feelings toward").add("how you feel about");
	syn.add("some experiences you have had with");
	synonyms["relation"] = syn;

	syn.clear();
	syn.add("$whysay you are $afraidof /feared ?");
	syn.add("you seem terrified by /feared .");
	syn.add("when did you first feel $afraidof /feared ?");
	synonyms["fears"] = syn;

	syn.clear();
	syn.add("sure").add("positive").add("certain").add("absolutely sure");
	synonyms["sure"] = syn;

	syn.clear();
	syn.add("afraid of").add("frightened by").add("scared of");
	synonyms["afraidof"] = syn;

	syn.clear();
	syn.add("are you").add("have you been").add("have you been");
	synonyms["areyou"] = syn;

	syn.clear();
	syn.add("has something to do with").add("is related to");
	syn.add("could be the reason for").add("is caused by");
	syn.add("is because of");
	synonyms["isrelated"] = syn;

	syn.clear();
	syn.add("have something to do with");
	syn.add("are related to").add("could have caused");
	syn.add("could be the reason for");
	syn.add("are caused be").add("are because of");
	synonyms["arerelated"] = syn;
}

void init_synonyms2()
{
	SynonymList syn;

	syn.clear();
	syn.add("$areyou /found often ?");
	syn.add("what causes you to be /found ?");
	syn.add("$whysay you are /found ?");
	synonyms["moods"] = syn;

	syn.clear();
	syn.add("maybe").add("perhaps").add("possibly");
	synonyms["maybe"] = syn;

	syn.clear();
	syn.add("what happened when").add("what would happen if");
	synonyms["whatwhen"] = syn;

	syn.clear();
	syn.add("how do you do ?");
	syn.add("hello .").add("howdy!").add("hello .");
	syn.add("hi .").add("hi there .");
	synonyms["hello"] = syn;

	syn.clear();
	syn.add("dou you drink a lot of /found ?");
	syn.add("do you get drunk often ?");
	syn.add("$describe your drinking habits .");
	synonyms["drnk"] = syn;

	syn.clear();
	syn.add("dou you use /found often ?");
	syn.add("$aryou addicted to /found ?");
	syn.add("dou you realize that drugs can be very harmful ?");
	syn.add("$maybe you should try to quit using /found .");
	synonyms["drugs"] = syn;

	syn.clear();
	syn.add("$whysay /subj might $want /obj ?");
	syn.add("how does it feel to want ?");
	syn.add("why should /subj get /obj ?");
	syn.add("when did /subj first $want /obj ?");
	syn.add("$areyou obsessed with /obj ?");
	syn.add("why should i give /obj to /subj ?");
	syn.add("have you ever gotten /obj ?");
	synonyms["whywant"] = syn;

	syn.clear();
	syn.add("of course i can .");
	syn.add("why should i ?");
	syn.add("what makes you think i would even want to ?");
	syn.add("i am the doctor, i can do anything i damn please .");
	syn.add("not really, it's not up to me .");
	syn.add("depends, how important is it ?");
	syn.add("i could, but i don't think it would be a wise thing to do .");
	syn.add("can you ?");
	syn.add("$maybe i can, $maybe i can't ...");
	syn.add("i don't think i should do that .");
	synonyms["canyou"] = syn;

	syn.clear();
	syn.add("want").add("desire").add("wish").add("want").add("hope");
	synonyms["want"] = syn;

	syn.clear();
	syn.add("can you elaborate on that ?");
	syn.add("$please continue .");
	syn.add("go on, don't be afraid .");
	syn.add("i need a little more detail please .");
	syn.add("you're being a bit brief, $please go into detail .");
	syn.add("can you $please be more explicit ?");
	syn.add("and ?");
	syn.add("$please go into more detail ?");
	syn.add("you aren't being very talkative today!");
	syn.add("is that all there is to it ?");
	syn.add("Why must you respond so briefly ?");
	synonyms["shortlist"] = syn;

	syn.clear();
	syn.add("tell me $something about /owner family .");
	syn.add("you seem to dwell on /owner family .");
	syn.add("$areyou hung up on /owner family ?");
	synonyms["famlist"] = syn;

	syn.clear();
	syn.add("$whysay /sent ?");
	syn.add("is it because of $things that you say /sent ?");
	synonyms["huhlist"] = syn;
}


void init_synonyms3()
{
	SynonymList syn;

	syn.clear();
	syn.add("$whysay that ?");
	syn.add("i don't understand .");
	syn.add("$thlist");
	syn.add("$areyou $afraidof that ?");
	synonyms["longhuhlist"] = syn;

	syn.clear();
	syn.add("feelings about").add("apprehension toward");
	syn.add("thoughts on").add("emotions toward");
	synonyms["feelings-about"] = syn;

	syn.clear();
	syn.add("vivid").add("emotionally stimulating").add("exciting");
	syn.add("boring").add("interesting").add("recent").add("random");
	syn.add("unusual").add("shocking").add("embarrassing");
	synonyms["random-adjective"] = syn;

	syn.clear();
	syn.add("why do you say").add("what makes you believe");
	syn.add("are you sure that").add("do you really think");
	syn.add("what makes you think");
	synonyms["whysay"] = syn;

	syn.clear(),
	syn.add("i see ...").add("yes").add("i understand .").add("oh .");
	synonyms["isee"] = syn;

	syn.clear();
	syn.add("please,").add("i would appreciate it if you would");
	syn.add("perhaps you could").add("please,").add("would you please");
	syn.add("why don't you").add("could you");
	synonyms["please"] = syn;

	// This is used to determine if the patient wants to quit.
	syn.clear();
	syn.add("good bye").add("see you later").add("i quit").add("so long");
	syn.add("go away").add("get lost").add("bye").add("halt").add("break");
	syn.add("quit").add("done").add("exit").add("goodbye").add("stop");
	syn.add("pause").add("end");
	synonyms["byelist"] = syn;
}

void init_synonyms4()
{
	SynonymList syn;

	syn.clear();
	syn.add("my secretary will send you a bill .");
	syn.add("bye bye .").add("see ya .");
	syn.add("ok, talk to you some other time.");
	syn.add("talk to you later").add("ok, have fun .").add("ciao .");
	synonyms["bye"] = syn;

	syn.clear();
	syn.add("something").add("more").add("how you feel");
	synonyms["something"] = syn;

	syn.clear();
	syn.add("your plans").add("your life");
	syn.add("the people you hang around with").add("problems at school");
	syn.add("any hobbies you have").add("your sex life");
	syn.add("hangups you have").add("your inhibitions");
	syn.add("some problems in your childhood");
	syn.add("some problems at home");
	synonyms["things"] = syn;

	syn.clear();
	syn.add("describe").add("tell me about").add("talk about");
	syn.add("discuss").add("tell me more about").add("elaborate on");
	synonyms["describe"] = syn;

	syn.clear();
	syn.add("i believe").add("i think").add("i have a feeling");
	syn.add("it seems to me that").add("it looks like");
	synonyms["ibelieve"] = syn;

	syn.clear();
	syn.add("problems").add("inhibitions").add("hangups");
	syn.add("difficulties").add("anxieties").add("frustrations");
	synonyms["problems"] = syn;

	syn.clear();
	syn.add("does it bother you that").add("are you annoyed that");
	syn.add("did you ever regret").add("are you sorry");
	syn.add("are you satisfied with the fact that");
	synonyms["bother"] = syn;

	syn.clear();
	syn.add("you have your mind on /found , it seems .");
	syn.add("you think too much about /found .");
	syn.add("you should try taking your mind off of /found .");
	syn.add("are you a computer hacker ?");
	synonyms["machlist"] = syn;

	syn.clear();
	syn.add("what do you think ?");
	syn.add("i'll ask the questions, if you don't mind!");
	syn.add("i could ask the same thing myself .");
	syn.add("$please allow me to do the questioning .");
	syn.add("i have asked myself that question many times .");
	syn.add("$please try to answer that question yourself .");
	syn.add("telling you this would waste precious time and money .");
	syn.add("this is a therapy session, not a coffee break .");
	synonyms["qlist"] = syn;

	syn.clear();
	syn.add("$please watch your tongue!");
	syn.add("$please avoid such unwholesome thoughts .");
	syn.add("$please get your mind out of the gutter .");
	syn.add("such lewdness is not appreciated .");
	synonyms["foullist"] = syn;

	syn.clear();
	syn.add("this is not a healthy way of thinking .");
	syn.add("$bother you, too, may die someday ?");
	syn.add("i am worried by your obsession with this topic!");
	syn.add("did you watch a lot of crime and violence on television as a child ?");
	synonyms["deathlist"] = syn;

	syn.clear(),
	syn.add("$areyou $afraidof sex ?");
	syn.add("$describe $something about your sexual history .");
	syn.add("$please $describe your sex life ...");
	syn.add("$describe your $feelings-about your sexual partner .");
	syn.add("$describe your most $random-adjective sexual experience .");
	syn.add("$areyou satisfied with /lover ... ?");
	synonyms["sexlist"] = syn;

}

void init_synonyms5()
{
	SynonymList syn;

	syn.clear(),
	syn.add("why not ?").add("$bother i ask that ?").add("why not ?");
	syn.add("why not ?").add("how come ?").add("$bother i ask that ?");
	synonyms["neglist"] = syn;

	syn.clear();
	syn.add("is it because /sent that you came to me ?");
	syn.add("$bother /sent ?");
	syn.add("when did you first know that /sent ?");
	syn.add("is the fact that /sent the reals reason ?");
	syn.add("does the fact that /sent explain anything else ?");
	syn.add("$areyou $sure /sent ?");
	synonyms["beclist"] = syn;

	syn.clear();
	syn.add("$bother i ask you that ?");
	syn.add("that's not much of an answer!");
	syn.add("$inter why won't you talk about it ?");
	syn.add("speak up!").add("$areyou $afraidof talking about it ?");
	syn.add("don't be $afraidof elaborating .");
	syn.add("$please go into more detail .");
	synonyms["shortbeclist"] = syn;

	syn.clear();
	syn.add("$maybe $things $arerelated this .");
	syn.add("is it because of $things that you are going through all this ?");
	syn.add("how do you reconcile $things ?");
	syn.add("$maybe this $isrelated $things ?");
	synonyms["thlist"] = syn;

	syn.clear();
	syn.add("earlier you said $history ?");
	syn.add("you mentioned that $history ?");
	syn.add("$whysay $history ?");
	synonyms["remlist"] = syn;

	syn.clear();
	syn.add("is this how you relax ?");
	syn.add("how long have you been smoking grass ?");
	syn.add("$areyou $afraidof of being drawn to using harder stuff ?");
	synonyms["toklist"] = syn;

	syn.clear();
	syn.add("do you get /found often ?");
	syn.add("dou you enjoy being /found ?");
	syn.add("what makes you /found ?");
	syn.add("how often $areyou /found ?");
	syn.add("when were you last /found ?");
	synonyms["states"] = syn;

	syn.clear();
	syn.add("$describe your $feelings-about him.");
	syn.add("$areyou a friend of Stallman ?");
	syn.add("$bother Stallman is $random-adjective ?");
	syn.add("$ibelieve you are $afraidof him .");
	synonyms["stallmanlist"] = syn;

	syn.clear();
	syn.add("$describe your /found .");
	syn.add("$bother your grades could $improve ?");
	syn.add("$areyou $afraidof /found ?");
	syn.add("$maybe this $isrelated to your attitude .");
	syn.add("$areyou absent often ?");
	syn.add("$maybe you should study $something .");
	synonyms["schoollist"] = syn;

	syn.clear();
	syn.add("improve").add("be better").add("be improved");
	syn.add("be higher");
	synonyms["improve"] = syn;

	syn.clear();
	syn.add("$areyou $sure ?");
	syn.add("$ibelieve you have $problems with /found .");
	syn.add("$whysay /sent ?");
	synonyms["elizalist"] = syn;

	syn.clear();
	syn.add("tell me $something about /found .");
	syn.add("$describe $relation /found .");
	syn.add("do you find /found $random-adjective ?");
	synonyms["sportslist"] = syn;

}


void init_synonyms()
{
	init_synonyms1();
	init_synonyms2();
	init_synonyms3();
	init_synonyms4();
	init_synonyms5();

	SynonymList syn;

	syn.clear();
	syn.add("$describe $something about math .");
	syn.add("$maybe your $problems $arerelated /found .");
	syn.add("i don't know much /found , but $continue anyway .");
	synonyms["mathlist"] = syn;

	syn.clear();
	syn.add("$areyou Zippy ?");
	syn.add("$ibelieve you have some serious $problems .");
	syn.add("$bother you are a pinhead ?");
	synonyms["zippylist"] = syn;

	syn.clear();
	syn.add("$maybe we could chat .");
	syn.add("$please $describe $something about chat mode .");
	syn.add("$bother our discussion is so $random-adjective ?");
	synonyms["chatlist"] = syn;

	syn.clear();
	syn.add("$please try to be less abusive .");
	syn.add("$describe why you call me /found .");
	syn.add("i've had enough of you!");
	synonyms["abuselist"] = syn;

	syn.clear();
	syn.add("boring").add("bozo").add("clown").add("clumsy").add("cretin");
	syn.add("dumb").add("dummy").add("fool").add("foolish").add("gnerd");
	syn.add("gnurd").add("idiot").add("jerk").add("lose").add("loser");
	syn.add("louse").add("lousy").add("luse").add("luser").add("moron");
	syn.add("nerd").add("nurd").add("oaf").add("oafish").add("reek");
	syn.add("stink").add("stupid").add("tool").add("toolish").add("twit"),
	synonyms["abusewords"] = syn;

	syn.clear();
	syn.add("how are you").add("hows it going").add("hows it going eh");
	syn.add("how's it going").add("how's it going eh").add("how goes it");
	syn.add("whats up").add("whats new").add("what's up");
	syn.add("what's new").add("howre you").add("how're you");
	syn.add("how's everything").add("how is everything");
	syn.add("how do you do").add("how's it hanging").add("que pasa");
	syn.add("how are you doing").add("what do you say");
	synonyms["howareyoulist"] = syn;

	syn.clear();
	syn.add("huh").add("remem").add("rthing");
	synonyms["whereoutp"] = syn;

	// This is not in Emacs doctor
	syn.clear();
	syn.add("who is your creator").add("who programmed you");
	syn.add("by whom were you programmed").add("who has created you");
	syn.add("who has programmed you").add("who is your programmer");
	syn.add("what's the name of your creator");
	syn.add("what's the name of your programmer");
	synonyms["whocreator"] = syn;
}

